@@ -1,6 +1,5 @@
 import asyncio
 import os
-import re
 import shutil
 import subprocess
 import sys
@@ -41,6 +40,7 @@ from .utils import (
     get_app_path,
     get_app_src_path,
     is_djelm,
+    is_elm_entrypoint,
     is_elm_file_string,
     is_ts_file_string,
     module_name,
@@ -420,15 +420,17 @@ class CompileStrategy:
                 COMPILE_PROGRAM = f"""
                 "use strict";
                 const _core = require("@parcel/core");
+
                 let bundler = new _core.Parcel({{
                   entries: "./{os.path.join(*STUFF_ENTRYPOINTS)}/*.ts",
                   defaultConfig: "@parcel/config-default",
-                  mode: {"'production'" if self.build else "'development'"},
+                  mode: "{"production" if self.build else "development"}",
                   defaultTargetOptions: {{
                     distDir: "../static/dist",
                     outputFormat: "esmodule",
                   }},
                 }});
+
                 async function Main() {{
                   try {{
                     let {{ bundleGraph, buildTime }} = await bundler.run();
@@ -467,7 +469,7 @@ class CompileStrategy:
         for file in files:
             if "handlers.ts" in file:
                 imports.append(
-                    f"import {{ handlePorts }} from '../../../src/{base_path}{file}'"
+                    f"import * as handlers from '../../../src/{base_path}{file}'"
                 )
         return imports
 
@@ -475,7 +477,9 @@ class CompileStrategy:
         extras = []
         for file in files:
             if "handlers.ts" in file:
-                extras.append("handlePorts(app.ports);")
+                extras.append(
+                    """if (handlers && typeof handlers.handleApp === 'function') handlers.handleApp(app);"""
+                )
         return extras
 
 
@@ -602,9 +606,7 @@ class FindProgramsStrategy:
             handle = await aiofiles.open(os.path.join(base_dir, file))
             content = await handle.read()
             await handle.close()
-            if re.search(
-                r"^(main : Program Value Model Msg)", content, flags=re.MULTILINE
-            ):
+            if is_elm_entrypoint(content):
                 program_name = os.path.splitext(file)[0]
                 supporting_files = supporting_ts_files(program_name)
                 ts_files = ts_files_lookup.get(base_dir, [])
